@@ -28,49 +28,6 @@
 
 G_BEGIN_DECLS
 
-#define GOSSIP_TYPE_CHATROOM             (gossip_chatroom_get_gtype ())
-#define GOSSIP_CHATROOM(o)               (G_TYPE_CHECK_INSTANCE_CAST ((o), GOSSIP_TYPE_CHATROOM, GossipChatroom))
-#define GOSSIP_CHATROOM_CLASS(k)         (G_TYPE_CHECK_CLASS_CAST ((k), GOSSIP_TYPE_CHATROOM, GossipChatroomClass))
-#define GOSSIP_IS_CHATROOM(o)            (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOSSIP_TYPE_CHATROOM))
-#define GOSSIP_IS_CHATROOM_CLASS(k)      (G_TYPE_CHECK_CLASS_TYPE ((k), GOSSIP_TYPE_CHATROOM))
-#define GOSSIP_CHATROOM_GET_CLASS(o)     (G_TYPE_INSTANCE_GET_CLASS ((o), GOSSIP_TYPE_CHATROOM, GossipChatroomClass))
-
-#define GOSSIP_TYPE_CHATROOM_INVITE       (gossip_chatroom_invite_get_gtype ())
-
-typedef struct _GossipChatroom            GossipChatroom;
-typedef struct _GossipChatroomClass       GossipChatroomClass;
-typedef struct _GossipChatroomContactInfo GossipChatroomContactInfo;
-typedef struct _GossipChatroomInvite      GossipChatroomInvite;
-typedef gint                              GossipChatroomId;
-
-/*
- * Privilege  	                        None  	Visitor  Participant  	Moderator
-
- * Present in Room  	                No  	Yes  	 Yes  		Yes
- * Receive Messages 	                No 	Yes 	 Yes 		Yes
- * Change Availability Status 	        No 	Yes 	 Yes 		Yes
- * Change Room Nickname 	        No 	Yes* 	 Yes 		Yes
- * Send Private Messages 	        No 	Yes* 	 Yes 		Yes
- * Invite Other Users 	                No 	Yes* 	 Yes* 		Yes
- * Send Messages to All 	        No 	No** 	 Yes 		Yes
- * Modify Subject 	                No 	No* 	 Yes* 		Yes
- * Kick Participants and Visitors 	No 	No 	 No 		Yes
- * Grant Voice 	                        No 	No 	 No 		Yes
- * Revoke Voice 	                No 	No 	 No 		Yes***
- *
- * - *   Default; configuration settings MAY modify this privilege.
- * - **  An implementation MAY grant voice by default to visitors in unmoderated rooms.
- * - *** A moderator MUST NOT be able to revoke voice privileges from an admin or owner.
- */
-
-struct _GossipChatroom {
-	GObject parent;
-};
-
-struct _GossipChatroomClass {
-	GObjectClass parent_class;
-};
-
 typedef enum {
 	GOSSIP_CHATROOM_AFFILIATION_OWNER,
 	GOSSIP_CHATROOM_AFFILIATION_ADMIN,
@@ -109,21 +66,85 @@ typedef enum {
 	GOSSIP_CHATROOM_FEATURE_UNSECURED            = 1 << 11
 } GossipChatroomFeature;
 
+/*
+ * GossipChatroomError
+ */ 
+#define GOSSIP_TYPE_CHATROOM_ERROR (gossip_chatroom_error_get_type ())
+
 typedef enum {
-	GOSSIP_CHATROOM_TYPE_NORMAL,
-} GossipChatroomType;
+	GOSSIP_CHATROOM_ERROR_NONE,
+
+	/* MUC errors */
+	GOSSIP_CHATROOM_ERROR_PASSWORD_INVALID_OR_MISSING,
+	GOSSIP_CHATROOM_ERROR_USER_BANNED,
+	GOSSIP_CHATROOM_ERROR_ROOM_NOT_FOUND,
+	GOSSIP_CHATROOM_ERROR_ROOM_CREATION_RESTRICTED,
+	GOSSIP_CHATROOM_ERROR_USE_RESERVED_ROOM_NICK,
+	GOSSIP_CHATROOM_ERROR_NOT_ON_MEMBERS_LIST,
+	GOSSIP_CHATROOM_ERROR_NICK_IN_USE,
+	GOSSIP_CHATROOM_ERROR_MAXIMUM_USERS_REACHED,
+
+	/* Internal errors */
+	GOSSIP_CHATROOM_ERROR_ALREADY_OPEN,
+	GOSSIP_CHATROOM_ERROR_TIMED_OUT,
+	GOSSIP_CHATROOM_ERROR_CANCELED,
+	GOSSIP_CHATROOM_ERROR_UNKNOWN
+} GossipChatroomError;
+
+GType gossip_chatroom_error_get_type (void) G_GNUC_CONST;
+
+/*
+ * GossipChatroom
+ */
+#define GOSSIP_TYPE_CHATROOM             (gossip_chatroom_get_type ())
+#define GOSSIP_CHATROOM(o)               (G_TYPE_CHECK_INSTANCE_CAST ((o), GOSSIP_TYPE_CHATROOM, GossipChatroom))
+#define GOSSIP_CHATROOM_CLASS(k)         (G_TYPE_CHECK_CLASS_CAST ((k), GOSSIP_TYPE_CHATROOM, GossipChatroomClass))
+#define GOSSIP_IS_CHATROOM(o)            (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOSSIP_TYPE_CHATROOM))
+#define GOSSIP_IS_CHATROOM_CLASS(k)      (G_TYPE_CHECK_CLASS_TYPE ((k), GOSSIP_TYPE_CHATROOM))
+#define GOSSIP_CHATROOM_GET_CLASS(o)     (G_TYPE_INSTANCE_GET_CLASS ((o), GOSSIP_TYPE_CHATROOM, GossipChatroomClass))
+
+typedef struct _GossipChatroom            GossipChatroom;
+typedef struct _GossipChatroomClass       GossipChatroomClass;
+typedef struct _GossipChatroomContactInfo GossipChatroomContactInfo;
+typedef gint                              GossipChatroomId;
+
+/*
+ * Privilege  	                        None  	Visitor  Participant  	Moderator
+
+ * Present in Room  	                No  	Yes  	 Yes  		Yes
+ * Receive Messages 	                No 	Yes 	 Yes 		Yes
+ * Change Availability Status 	        No 	Yes 	 Yes 		Yes
+ * Change Room Nickname 	        No 	Yes* 	 Yes 		Yes
+ * Send Private Messages 	        No 	Yes* 	 Yes 		Yes
+ * Invite Other Users 	                No 	Yes* 	 Yes* 		Yes
+ * Send Messages to All 	        No 	No** 	 Yes 		Yes
+ * Modify Subject 	                No 	No* 	 Yes* 		Yes
+ * Kick Participants and Visitors 	No 	No 	 No 		Yes
+ * Grant Voice 	                        No 	No 	 No 		Yes
+ * Revoke Voice 	                No 	No 	 No 		Yes***
+ *
+ * - *   Default; configuration settings MAY modify this privilege.
+ * - **  An implementation MAY grant voice by default to visitors in unmoderated rooms.
+ * - *** A moderator MUST NOT be able to revoke voice privileges from an admin or owner.
+ */
+
+struct _GossipChatroom {
+	GObject      parent;
+};
+
+struct _GossipChatroomClass {
+	GObjectClass parent_class;
+};
 
 struct _GossipChatroomContactInfo {
 	GossipChatroomRole        role;
 	GossipChatroomAffiliation affiliation;
 };
 
-GType             gossip_chatroom_get_gtype            (void) G_GNUC_CONST;
-GType             gossip_chatroom_invite_get_gtype     (void) G_GNUC_CONST;
+/* Chatroom */
+GType             gossip_chatroom_get_type             (void) G_GNUC_CONST;
 
-/* Gets */
-GossipChatroomType
-                  gossip_chatroom_get_type             (GossipChatroom  *chatroom);
+GossipAccount *   gossip_chatroom_get_account          (GossipChatroom  *chatroom);
 GossipChatroomId  gossip_chatroom_get_id               (GossipChatroom  *chatroom);
 const gchar *     gossip_chatroom_get_id_str           (GossipChatroom  *chatroom);
 const gchar *     gossip_chatroom_get_name             (GossipChatroom  *chatroom);
@@ -140,15 +161,14 @@ GossipChatroomFeature
 GossipChatroomStatus
                   gossip_chatroom_get_status           (GossipChatroom  *chatroom);
 guint             gossip_chatroom_get_occupants        (GossipChatroom  *chatroom);
-const gchar *     gossip_chatroom_get_last_error       (GossipChatroom  *chatroom);
-GossipAccount *   gossip_chatroom_get_account          (GossipChatroom  *chatroom);
+GossipChatroomError
+                  gossip_chatroom_get_last_error       (GossipChatroom  *chatroom);
 GossipChatroomContactInfo *
                   gossip_chatroom_get_contact_info     (GossipChatroom  *chatroom,
 							GossipContact   *contact);
 
-/* Sets */
-void              gossip_chatroom_set_type             (GossipChatroom  *chatroom,
-							GossipChatroomType type);
+void              gossip_chatroom_set_account          (GossipChatroom  *chatroom,
+							GossipAccount   *account);
 void              gossip_chatroom_set_name             (GossipChatroom  *chatroom,
 							const gchar     *name);
 void              gossip_chatroom_set_description      (GossipChatroom  *chatroom,
@@ -174,9 +194,7 @@ void              gossip_chatroom_set_status           (GossipChatroom  *chatroo
 void              gossip_chatroom_set_occupants        (GossipChatroom  *chatroom,
 							guint            occupants);
 void              gossip_chatroom_set_last_error       (GossipChatroom  *chatroom,
-							const gchar     *last_error);
-void              gossip_chatroom_set_account          (GossipChatroom  *chatroom,
-							GossipAccount   *account);
+							GossipChatroomError last_error);
 void              gossip_chatroom_set_contact_info     (GossipChatroom  *chatroom,
 							GossipContact   *contact,
 							GossipChatroomContactInfo *info);
@@ -187,8 +205,8 @@ gboolean          gossip_chatroom_equal                 (gconstpointer   v1,
 							 gconstpointer   v2);
 gboolean          gossip_chatroom_equal_full            (gconstpointer   v1,
 							 gconstpointer   v2);
-const gchar *     gossip_chatroom_type_to_string        (GossipChatroomType type);
 const gchar *     gossip_chatroom_status_to_string      (GossipChatroomStatus status);
+const gchar *     gossip_chatroom_error_to_string       (GossipChatroomError error);
 const gchar *     gossip_chatroom_role_to_string        (GossipChatroomRole role,
 							 gint               nr);
 const gchar *
@@ -199,20 +217,6 @@ void              gossip_chatroom_contact_joined        (GossipChatroom  *chatro
 							 GossipChatroomContactInfo *info);
 void              gossip_chatroom_contact_left          (GossipChatroom  *chatroom,
 							 GossipContact   *contact);
-/* Invite functions */
-GType             gossip_chatroom_invite_get_type       (void) G_GNUC_CONST;
-GossipChatroomInvite *
-                  gossip_chatroom_invite_new            (GossipContact   *invitor,
-							 const gchar     *id,
-							 const gchar     *reason);
-GossipChatroomInvite *
-                  gossip_chatroom_invite_ref            (GossipChatroomInvite *invite);
-
-void              gossip_chatroom_invite_unref          (GossipChatroomInvite *invite);
-
-GossipContact *   gossip_chatroom_invite_get_invitor    (GossipChatroomInvite *invite);
-const gchar *     gossip_chatroom_invite_get_id         (GossipChatroomInvite *invite);
-const gchar *     gossip_chatroom_invite_get_reason     (GossipChatroomInvite *invite);
 
 G_BEGIN_DECLS
 
