@@ -16,9 +16,6 @@
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- *
- * Authors: Mikael Hallendal <micke@imendio.com>
- *          Martyn Russell <martyn@imendio.com>
  */
 
 #include "config.h"
@@ -49,6 +46,8 @@ struct _GossipContactPriv {
 	GossipSubscription  subscription;
 	GossipAvatar       *avatar;
 	GossipAccount      *account;
+
+	GossipVCard        *vcard;
 };
 
 static void contact_class_init    (GossipContactClass *class);
@@ -62,8 +61,6 @@ static void contact_set_property  (GObject            *object,
 				   guint               param_id,
 				   const GValue       *value,
 				   GParamSpec         *pspec);
-static void contact_set_type      (GossipContact      *contact,
-				   GossipContactType   type);
 static void contact_set_presences (GossipContact      *contact,
 				   GList              *presences);
 
@@ -76,7 +73,8 @@ enum {
 	PROP_GROUPS,
 	PROP_SUBSCRIPTION,
 	PROP_AVATAR,
-	PROP_ACCOUNT
+	PROP_ACCOUNT,
+	PROP_VCARD
 };
 
 static gpointer parent_class = NULL;
@@ -184,6 +182,13 @@ contact_class_init (GossipContactClass *class)
 							      "The account associated with the contact",
 							      GOSSIP_TYPE_ACCOUNT,
 							      G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+					 PROP_VCARD,
+					 g_param_spec_object ("vcard",
+							      "Contact VCard",
+							      "The vcard for contact",
+							      GOSSIP_TYPE_VCARD,
+							      G_PARAM_READWRITE));
 
 	g_type_class_add_private (object_class, sizeof (GossipContactPriv));
 }
@@ -196,12 +201,6 @@ contact_init (GossipContact *contact)
 	priv = GET_PRIV (contact);
 
 	priv->type        = GOSSIP_CONTACT_TYPE_TEMPORARY;
-	priv->name        = NULL;
-	priv->id          = NULL;
-	priv->presences   = NULL;
-	priv->account     = NULL;
-	priv->groups      = NULL;
-	priv->avatar      = NULL;
 }
 
 static void
@@ -232,6 +231,10 @@ contact_finalize (GObject *object)
 		g_object_unref (priv->account);
 	}
 
+	if (priv->vcard) {
+		g_object_unref (priv->vcard);
+	}
+
 	(G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
@@ -272,6 +275,9 @@ contact_get_property (GObject    *object,
 	case PROP_ACCOUNT:
 		g_value_set_object (value, priv->account);
 		break;
+	case PROP_VCARD:
+		g_value_set_object (value, priv->vcard);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -290,8 +296,8 @@ contact_set_property (GObject      *object,
 
 	switch (param_id) {
 	case PROP_TYPE:
-		contact_set_type (GOSSIP_CONTACT (object),
-				  g_value_get_int (value));
+		gossip_contact_set_type (GOSSIP_CONTACT (object),
+					 g_value_get_int (value));
 		break;
 	case PROP_NAME:
 		gossip_contact_set_name (GOSSIP_CONTACT (object),
@@ -321,6 +327,10 @@ contact_set_property (GObject      *object,
 		gossip_contact_set_account (GOSSIP_CONTACT (object),
 					    GOSSIP_ACCOUNT (g_value_get_object (value)));
 		break;
+	case PROP_VCARD:
+		gossip_contact_set_vcard (GOSSIP_CONTACT (object),
+					  GOSSIP_VCARD (g_value_get_object (value)));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -467,6 +477,18 @@ gossip_contact_get_account (GossipContact *contact)
 	return priv->account;
 }
 
+GossipVCard *
+gossip_contact_get_vcard (GossipContact *contact)
+{
+	GossipContactPriv *priv;
+
+	g_return_val_if_fail (GOSSIP_IS_CONTACT (contact), NULL);
+
+	priv = GET_PRIV (contact);
+
+	return priv->vcard;
+}
+
 GossipPresence *
 gossip_contact_get_active_presence (GossipContact *contact)
 {
@@ -545,9 +567,9 @@ gossip_contact_get_subscription (GossipContact *contact)
 	return priv->subscription;
 }
 
-static void
-contact_set_type (GossipContact      *contact,
-		  GossipContactType   type)
+void
+gossip_contact_set_type (GossipContact     *contact,
+			 GossipContactType  type)
 {
 	GossipContactPriv *priv;
 
@@ -657,6 +679,25 @@ gossip_contact_set_account (GossipContact *contact,
 	g_object_notify (G_OBJECT (contact), "account");
 }
 
+void 
+gossip_contact_set_vcard (GossipContact *contact, GossipVCard *vcard)
+{
+	GossipContactPriv *priv;
+
+	g_return_if_fail (GOSSIP_IS_CONTACT (contact));
+	g_return_if_fail (GOSSIP_IS_VCARD (vcard));
+
+	priv = GET_PRIV (contact);
+
+	if (priv->vcard) {
+		g_object_unref (priv->vcard);
+	}
+
+	priv->vcard = g_object_ref (vcard);
+
+	g_object_notify (G_OBJECT (contact), "vcard");
+}
+
 void
 gossip_contact_add_presence (GossipContact  *contact,
 			     GossipPresence *presence)
@@ -923,3 +964,19 @@ gossip_contact_get_status (GossipContact *contact)
 	}
 }
 
+const gchar *
+gossip_contact_type_to_string (GossipContactType type)
+{
+	switch (type) {
+	case GOSSIP_CONTACT_TYPE_TEMPORARY:
+		return "GOSSIP_CONTACT_TYPE_TEMPORARY";
+	case GOSSIP_CONTACT_TYPE_CONTACTLIST:
+		return "GOSSIP_CONTACT_TYPE_CONTACTLIST";
+	case GOSSIP_CONTACT_TYPE_CHATROOM:
+		return "GOSSIP_CONTACT_TYPE_CHATROOM";
+	case GOSSIP_CONTACT_TYPE_USER:
+		return "GOSSIP_CONTACT_TYPE_USER";
+	}
+
+	return "";
+}
