@@ -32,7 +32,7 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
 #endif
@@ -64,7 +64,7 @@ int
 main (int argc, char *argv[])
 {
 	gchar                *localedir;
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	GnomeProgram         *program;
 #else
 	GError               *error = NULL;
@@ -106,8 +106,17 @@ main (int argc, char *argv[])
 
 	g_set_application_name (PACKAGE_NAME);
 
-#ifdef HAVE_GNOME
-	program = gnome_program_init ("gossip", PACKAGE_VERSION,
+#ifdef HAVE_PLATFORM_X11
+	/* This is really crap! On Windows, we can't use DATADIR because it
+	 * conflicts with a definition in the win32 header files meaning
+	 * Gossip won't compile. Here, we need it defined for
+	 * GNOME_PROGRAM_STANDARD_PROPERTIES which needs it. So we simply add
+	 * this hack below to keep everyone happy.
+	 */
+#define DATADIR SHAREDIR
+
+	program = gnome_program_init (PACKAGE_TARNAME, 
+				      PACKAGE_VERSION,
 				      LIBGNOMEUI_MODULE,
 				      argc, argv,
 				      GNOME_PROGRAM_STANDARD_PROPERTIES,
@@ -125,7 +134,7 @@ main (int argc, char *argv[])
 	}
 #endif
 
-	gossip_window_set_default_icon_name ("gossip");
+	gossip_window_set_default_icon_name (PACKAGE_TARNAME);
 
 	/* Get all accounts. */
 	session = gossip_session_new (NULL, NULL, NULL);
@@ -214,27 +223,10 @@ main (int argc, char *argv[])
 
 	gossip_stock_finalize ();
 
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	g_object_unref (program);
 #endif
 
 	return EXIT_SUCCESS;
 }
 
-/*
-
-  Still leaked from just starting up, connecting one account, disconnecting it
-  from the menu, quitting:
-
-  1 GossipAccount, 64 bytes
-  2 GossipPresence, 64 bytes
-  1 GossipJabber, 80 bytes
-  2 GossipContact, 104 bytes
-
-  Having a chat window open and connecting/disconnecting a few times before
-  quitting:
-
-  5 GossipAccount, 340 bytes
-  10 GossipContact, 520 bytes
-
-*/
