@@ -30,17 +30,25 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 #include <gdk/gdkx.h>
 #include <libgnome/gnome-url.h>
 #include <libgnomeui/libgnomeui.h>
-#elif defined (HAVE_COCOA)
+#elif defined (HAVE_PLATFORM_OSX)
 #include <Cocoa/Cocoa.h>
+#elif defined (HAVE_PLATFORM_WIN32)
+#ifdef HAVE_WINDOWS_H
+#include <windows.h>
+#endif /* HAVE_WINDOWS_H */
+#ifdef HAVE_SHELLAPI_H
+#include <shellapi.h>
+#endif /* HAVE_SHELLAPI_H */
 #endif
 
 #include <libgossip/gossip-session.h>
 #include <libgossip/gossip-account-manager.h>
 #include <libgossip/gossip-conf.h>
+#include <libgossip/gossip-debug.h>
 #include <libgossip/gossip-paths.h>
 #include <libgossip/gossip-stock.h>
 
@@ -51,83 +59,7 @@
 #include "gossip-app.h"
 #include "gossip-ui-utils.h"
 
-static void
-password_dialog_activate_cb (GtkWidget *entry, GtkDialog *dialog)
-{
-	gtk_dialog_response (dialog, GTK_RESPONSE_OK);
-}
-
-gchar *
-gossip_password_dialog_run (GossipAccount *account,
-			    GtkWindow     *parent)
-{
-	GtkWidget   *dialog;
-	GtkWidget   *checkbox;
-	GtkWidget   *entry;
-	GtkWidget   *vbox;
-	gchar       *str;
-	gchar       *password;
-	const gchar *name;
-
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), NULL);
-
-	str = g_strdup_printf (_("Please enter your %s account password"),
-			       gossip_account_get_name (account));
-	dialog = gtk_message_dialog_new_with_markup (parent,
-						     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_MESSAGE_QUESTION,
-						     GTK_BUTTONS_OK_CANCEL,
-						     "<b>%s</b>",
-						     str);
-	g_free (str);
-
-	name = gossip_account_get_name (account);
-	str = g_strdup_printf (_("Logging in to account '%s'"), name);
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", str);
-	g_free (str);
-
-	checkbox = gtk_check_button_new_with_label (_("Remember Password?"));
-
-	entry = gtk_entry_new ();
-	gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
-
-	g_signal_connect (entry,
-			  "activate",
-			  G_CALLBACK (password_dialog_activate_cb),
-			  dialog);
-
-	vbox = gtk_vbox_new (FALSE, 6);
-
-	gtk_container_set_border_width  (GTK_CONTAINER (vbox), 6);
-
-	gtk_box_pack_start (GTK_BOX (vbox), entry, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), checkbox, FALSE, FALSE, 0);
-
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox, FALSE, FALSE, 0);
-
-	gtk_widget_show_all (dialog);
-
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
-		password = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
-
-		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox))) {
-			GossipSession        *session;
-			GossipAccountManager *manager;
-
-			session = gossip_app_get_session ();
-			manager = gossip_session_get_account_manager (session);
-
-			gossip_account_set_password (account, password);
-			gossip_account_manager_store (manager);
-		}
-	} else {
-		password = NULL;
-	}
-
-	gtk_widget_destroy (dialog);
-
-	return password;
-}
+#define DEBUG_DOMAIN "UiUtils"
 
 GdkPixbuf *
 gossip_pixbuf_offline (void)
@@ -310,7 +242,7 @@ gossip_pixbuf_for_chatroom_status (GossipChatroom *chatroom,
  * like "www.gnome.org".
  */
 static gchar *
-fixup_url (const gchar *url)
+url_fixup (const gchar *url)
 {
 	gchar *real_url;
 
@@ -325,31 +257,41 @@ fixup_url (const gchar *url)
 	return real_url;
 }
 
-#ifdef HAVE_GNOME
-void
+#ifdef HAVE_PLATFORM_X11
+gboolean
 gossip_url_show (const char *url)
 {
 	gchar  *real_url;
 	GError *error = NULL;
 
-	real_url = fixup_url (url);
+	gossip_debug (DEBUG_DOMAIN, "Opening URL:'%s'...", url);
+
+	real_url = url_fixup (url);
 	gnome_url_show (real_url, &error);
+
 	if (error) {
 		g_warning ("Couldn't show URL:'%s'", real_url);
 		g_error_free (error);
+		g_free (real_url);
+
+		return FALSE;
 	}
 
 	g_free (real_url);
+
+	return TRUE;
 }
-#elif defined(HAVE_COCOA)
-void
+#elif defined(HAVE_PLATFORM_OSX)
+gboolean
 gossip_url_show (const char *url)
 {
 	gchar             *real_url;
 	NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
 	NSString          *string;
 
-	real_url = fixup_url (url);
+	gossip_debug (DEBUG_DOMAIN, "Opening URL:'%s'...", url);
+
+	real_url = url_fixup (url);
 
 	string = [NSString stringWithUTF8String: real_url];
 	[[NSWorkspace sharedWorkspace] openURL:[NSURL URLWithString:string]];
@@ -357,18 +299,110 @@ gossip_url_show (const char *url)
 	[pool release];
 
 	g_free (real_url);
+
+	return TRUE;
+}
+#elif defined(HAVE_PLATFORM_WIN32)
+#ifdef HAVE_SHELLAPI_H
+static const char *
+url_show_error_string (gint error)
+{
+#ifdef HAVE_WINDOWS_H
+	switch (error) {
+	case 0:                      
+		return "The operating system is out of memory or resources.";
+	case ERROR_FILE_NOT_FOUND:   
+		return "The specified file was not found.";
+	case ERROR_PATH_NOT_FOUND:   
+		return "The specified path was not found."; 
+	case ERROR_BAD_FORMAT:       
+		return "The .exe file is invalid (non-Microsoft Win32® .exe "
+		       "or error in .exe image).";
+	case SE_ERR_ACCESSDENIED:    
+		return "The operating system denied access to the specified file."; 
+	case SE_ERR_ASSOCINCOMPLETE: 
+		return "The file name association is incomplete or invalid."; 
+	case SE_ERR_DDEBUSY:         
+		return "The Dynamic Data Exchange (DDE) transaction could "
+		       "not be completed because other DDE transactions were "
+		       "being processed.";
+	case SE_ERR_DDEFAIL:         
+		return "The DDE transaction failed.";
+	case SE_ERR_DDETIMEOUT:      
+		return "The DDE transaction could not be completed because "
+		       "the request timed out.";
+	case SE_ERR_DLLNOTFOUND:     
+		return "The specified dynamic-link library (DLL) was not found.";
+		/*     case SE_ERR_FNF: return "The specified file was not found."; */
+	case SE_ERR_NOASSOC:         
+		return "There is no application associated with the given file "
+		       "name extension. This error will also be returned if you "
+		       "attempt to print a file that is not printable.";
+	case SE_ERR_OOM:             
+		return "There was not enough memory to complete the operation.";
+		/*     case SE_ERR_PNF: return "The specified path was not found."; */
+	case SE_ERR_SHARE:           
+		return "A sharing violation occurred.";
+	}
+#endif /* HAVE_WINDOWS_H */
+
+	return "";
+}
+#endif /* HAVE_SHELLAPI_H */
+
+gboolean 
+gossip_url_show (const gchar *url)
+{
+	gchar     *real_url;
+	gboolean   success = TRUE;
+	HINSTANCE  error;
+
+	g_return_val_if_fail (url != NULL, FALSE);
+
+	real_url = url_fixup (url);
+
+#ifdef HAVE_SHELLAPI_H    
+	gossip_debug (DEBUG_DOMAIN, "Opening URL:'%s'...", real_url);
+
+	error = ShellExecute ((HWND)NULL, /* parent window */
+			      "open",     /* verb */
+			      real_url,   /* file */
+			      NULL,       /* parameters */
+			      NULL,       /* path */
+			      SW_SHOWNORMAL);
+  
+	if ((gint)error <= 32) {
+		g_warning ("Failed to open URL:'%s', error:%d->'%s'", 
+			   real_url, 
+			   (gint) error, 
+			   url_show_error_string ((gint) error));
+		success = FALSE;
+	}
+
+#else  /* HAVE_SHELLAPI_H */
+	g_warning ("Failed to open url:'%s', operation not supported on this platform", 
+		   real_url);
+	success = FALSE;
+#endif /* HAVE_SHELLAPI_H */
+
+	g_free (real_url);
+
+	return success;
 }
 #else
 void
 gossip_url_show (const char *url)
 {
+	gchar *real_url;
+	real_url = url_fixup (url);
+	g_free (real_url);
 }
 #endif
 
 void
 gossip_help_show (void)
 {
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	gboolean   ok;
 	GtkWidget *dialog;
 	GError    *err = NULL;
@@ -393,7 +427,7 @@ gossip_help_show (void)
 	gtk_widget_show (dialog);
 
 	g_error_free (err);
-#elif defined(HAVE_COCOA)
+#elif defined(HAVE_PLATFORM_OSX)
 	/* Nothing for now. */
 #endif
 }
@@ -424,9 +458,9 @@ gossip_link_button_new (const gchar *url,
 void
 gossip_window_set_default_icon_name (const gchar *name)
 {
-#ifdef HAVE_GNOME
+#ifndef GDK_WINDOWING_QUARTZ
 	gtk_window_set_default_icon_name (name);
-#elif defined(HAVE_COCOA)
+#else
 	NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
 	gchar             *path;
 	NSString          *tmp;
@@ -448,9 +482,9 @@ gossip_window_set_default_icon_name (const gchar *name)
 void
 gossip_request_user_attention (void)
 {
-#ifdef HAVE_GNOME
+#ifdef HAVE_PLATFORM_X11
 	/* Nothing for now. */
-#elif defined(HAVE_COCOA)
+#elif defined(HAVE_PLATFORM_OSX)
 	NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
 	[NSApp requestUserAttention: NSInformationalRequest];
 	[pool release];
